@@ -7,27 +7,27 @@
 #ifndef UTF8_INC
 #define UTF8_INC
 
-#include <iostream>
+#include <stdio.h>
 #include "convkit.h"
 
 class UTF8Reader : public TextReader {
 public:
-    UTF8Reader(std::istream& input) : input(input) {}
+    UTF8Reader(FILE* input) : input(input) {}
 
     bool Read(unichar& c);
 
 private:
-    std::istream& input;
+    FILE* input;
 };
 
 class UTF8Writer : public TextWriter {
 public:
-    UTF8Writer(std::ostream& output) : output(output) {}
+    UTF8Writer(FILE* output) : output(output) {}
 
     bool Write(unichar c);
 
 private:
-    std::ostream& output;
+    FILE* output;
 };
 
 #endif  // UTF8_INC
